#!/bin/bash

PROT="simp_asan.prt"

# My standard work directory. Results of runs are in sub directories.
BATCH_WORKDIR="storage"
mkdir $BATCH_WORKDIR

# My standard var directory on tmpfs. Ongoing RQG runs are in sub directories.
BATCH_VARDIR="/dev/shm/vardir"
mkdir $BATCH_VARDIR


# Go with heavy load
PARALLEL=`nproc`
PARALLEL=$(($PARALLEL + $PARALLEL / 2))
echo $PARALLEL

TRIALS=$(($PARALLEL * 4))
TRIALS=$PARALLEL

# TRIALS=1
# PARALLEL=1

# Various settings for the server+InnoDB etc.
# including settings for avoiding open bugs.
CONFIG=simp_asan.cfg

if [ ! -e "$CONFIG" ]
then
   echo "The config file '$CONFIG' does not exist."
   echo "Please adjust the setting in $0"
   exit
fi


# One 'God' only
# --------------
# in order to avoid "ill" runs where
# - current rqg_batch run ---- other ongoing rqg_batch run
# - current rqg_batch run ---- ongoing MTR run
# clash on the same resources (vardir, ports -> MTR_BUILD_THREAD) or
# suffer from tmpfs full etc.
killall -9 perl ; killall -9 mysqld
rm -rf $BATCH_VARDIR/* rm -rf /dev/shm/var_*

# Path to MariaDB binaries
export ASAN_OPTIONS=abort_on_error=1,disable_coredump=0
BASEDIR=/home/mleich/Server/10.2/bld_asan

set -o pipefail
# --dryrun                                                       \
# --discard_logs Remove the logs of RQG runs achieving STATUS_OK/verdict 'ignore'
# --force    Do not abort if hitting Perl errors or STATUS_ENVIRONMENT_FAILURE. Unclear if good.
# --no-mask  Unclear if ./rqg_batch.pl and rqg.pl will mask at all.
# --type=RQG_Simplifier                                             \
# --dryrun=ignore                                                \
# --dryrun=replay                                                \
# --stop_on_replay                                                \
# --trials=$TRIALS                                                \
# --script_debug=_all_                                            \
  GRAMMAR=simp_asan.yy 
  vi $GRAMMAR
nohup perl -w ./rqg_batch.pl                                    \
--workdir=$BATCH_WORKDIR                                        \
--vardir=$BATCH_VARDIR                                          \
--parallel=$PARALLEL                                            \
--basedir1=$BASEDIR                                             \
--config=$CONFIG                                                \
  --stop_on_replay                                              \
  --grammar=$GRAMMAR                                            \
  --threads=1                                                   \
  --trials=$TRIALS                                              \
  --discard_logs                                                \
--duration=300                                                  \
--type=RQG_Simplifier                                           \
--no-mask                                                       \
> $PROT 2>&1 &
tail -f $PROT


